power_state library

Classes

NotifyInfo
PowerBuilder<T extends PowerController>
This widget is responsible for building a widget subtree based on the state of a PowerController instance.
PowerController
PowerSelector<T extends PowerController>
PowerVault
The PowerVault class provides a way to store and retrieve dependencies (such as controllers or services) as singletons, allowing shared instances across an application.