NotifyInfo class
Constructors
- NotifyInfo(VoidCallback listener, Type notifierType, {dynamic currentValue, dynamic prevValue, Object selector()?})
Properties
- currentValue ↔ dynamic
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- listener → VoidCallback
-
final
- notifierType → Type
-
final
- prevValue ↔ dynamic
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selector ↔ Object Function()?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited