PowerController class

Constructors

PowerController()

Properties

hashCode int
The hash code for this object.
no setterinherited
lisenerLength → dynamic
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(int key, NotifyInfo notifyInfo) → void
Register a closure to be called when the object notifies its listeners.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
removeListener(int key) → void
Remove a previously registered closure from the list of closures that the object notifies.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited