addListener method
Register a closure to be called when the object notifies its listeners.
Implementation
@override
void addListener(int key, NotifyInfo notifyInfo) {
_listeners[key] = notifyInfo;
}
Register a closure to be called when the object notifies its listeners.
@override
void addListener(int key, NotifyInfo notifyInfo) {
_listeners[key] = notifyInfo;
}